MDS Mosaic Utilities
---------------------

This package provides light wrappers around the SOAP interfaces provided by the MOSAIC suite of the `THS Greifswald <https://www.ths-greifswald.de/en/projekte/mosaic-project/>`_.
It exposes ``gpas`` and ``epix`` to interact with the eponymous services gPAS and E-PIX.
